@@ -1,6 +1,4 @@
 /*- This is a -*- C -*- compatible code file
- *
- * RCS $Id: kernel_sunos5.c,v 1.13.4.3 1999/06/04 18:53:31 nba Exp $
  *
  * Code for SUNOS5_INSTRUMENTATION
  *
@@ -12,6 +10,7 @@
  * This file contains function to obtain statistics from SunOS 5.x kernel
  *
  */
+
 #include <config.h>
 #ifdef solaris2
 /*-
@@ -55,9 +54,12 @@
 #include "../../snmplib/system.h"
 #include "asn1.h"
 #include "snmp_debug.h"
+#include "mibincl.h"
 
 #include "kernel_sunos5.h"
 
+kstat_ctl_t *kstat_fd = 0;
+
 /*-
  * Global variable definitions (with initialization)
  */
@@ -115,16 +117,17 @@ static	int		sd = -1;	/* /dev/ip stream descriptor. */
  */
 
 static found_e
-getentry(req_e req_type, void *bufaddr, int len, int entrysize,
-void *resp, int (*comp)(void *, void *), void *arg);
+getentry(req_e req_type, void *bufaddr, size_t len, size_t entrysize,
+	void *resp, int (*comp)(void *, void *), void *arg);
 
 static int
-getmib(int groupname, int subgroupname, void *statbuf, size_t size, int entrysize,
-req_e req_type, void *resp, int *length, int (*comp)(void *, void *), void *arg);
+getmib(int groupname, int subgroupname, void *statbuf, size_t size,
+	size_t entrysize, req_e req_type, void *resp, size_t *length,
+	int (*comp)(void *, void *), void *arg);
 
 static int
 getif(mib2_ifEntry_t *ifbuf, size_t size, req_e req_type, mib2_ifEntry_t *resp,
-int *length, int (*comp)(void *, void *), void *arg);
+	size_t *length, int (*comp)(void *, void *), void *arg);
 
 static int
 Name_cmp(void *, void *);
@@ -159,29 +162,75 @@ extern "C" {
    interface. :-(*/
 
 
-int getKstatInt(char *classname, char *statname, char *varname, int *value)
+int getKstatInt(const char *classname, const char *statname,
+		const char *varname, int *value)
 {
-    kstat_ctl_t *ksc = kstat_open();
+    kstat_ctl_t *ksc;
     kstat_t *ks;
     kid_t kid;
     kstat_named_t *named;
+    int ret = 0;  /* fail unless ... */
 
-    if (ksc == NULL) return 0;
+    if (kstat_fd == 0) {
+        kstat_fd = kstat_open();
+        if (kstat_fd == 0) {
+          snmp_log(LOG_ERR, "kstat_open(): failed\n");
+        }
+    }
+    if ((ksc = kstat_fd) == NULL)
+    {
+        goto Return;
+    }
     ks = kstat_lookup (ksc, classname, -1, statname);
-    if (ks == NULL) return 0;
+    if (ks == NULL) goto Return;
     kid = kstat_read (ksc, ks, NULL);
-    if (kid == -1) return 0;
+    if (kid == -1) goto Return;
     named = kstat_data_lookup(ks, varname);
-    if (named == NULL) return 0;
-    *value = named->value.ul;
-    kstat_close(ksc);
-    return 1;
+    if (named == NULL) goto Return;
+
+    ret = 1;	/* maybe successful */
+    switch (named->data_type) {
+#ifdef KSTAT_DATA_INT32		/* Solaris 2.6 and up */
+    case KSTAT_DATA_INT32:
+      *value = named->value.i32;
+      break;
+    case KSTAT_DATA_UINT32:
+      *value = named->value.ui32;
+      break;
+    case KSTAT_DATA_INT64:
+      *value = named->value.i64;
+      break;
+    case KSTAT_DATA_UINT64:
+      *value = named->value.ui64;
+      break;
+#else
+    case KSTAT_DATA_LONG:
+      *value = named->value.l;
+      break;
+    case KSTAT_DATA_ULONG:
+      *value = named->value.ul;
+      break;
+    case KSTAT_DATA_LONGLONG:
+      *value = named->value.ll;
+      break;
+    case KSTAT_DATA_ULONGLONG:
+      *value = named->value.ull;
+      break;
+#endif
+    default:
+      DEBUGMSGTL(("kernel_sunos5", "non-integer type in kstat data: %s %s %s %d\n",
+	      classname, statname, varname, named->data_type));
+      ret = 0;  /* fail */
+      break;
+    }
+Return:
+    return ret;
 }
 
 int
-getKstat(char *statname, char *varname, void *value)
+getKstat(const char *statname, const char *varname, void *value)
 {
-  kstat_ctl_t	*ksc;
+  kstat_ctl_t   *ksc;
   kstat_t	*ks, *kstat_data;
   kstat_named_t *d;
   size_t	i, instance;
@@ -194,7 +243,15 @@ getKstat(char *statname, char *varname, void *value)
     v = (void *)&val;
   else
     v = value;
-  if ((ksc = kstat_open()) == NULL) {
+
+    if (kstat_fd == 0) {
+        kstat_fd = kstat_open();
+        if (kstat_fd == 0) {
+          snmp_log(LOG_ERR, "kstat_open(): failed\n");
+        }
+    }
+  if ((ksc = kstat_fd) == NULL)
+  {
     ret = -10;
     goto Return;		/* kstat errors */
   }
@@ -254,24 +311,39 @@ getKstat(char *statname, char *varname, void *value)
 	*(char *)v = (int)d->value.c;
 	DEBUGMSGTL(("kernel_sunos5", "value: %d\n", (int)d->value.c));
 	break;
+#ifdef KSTAT_DATA_INT32		/* Solaris 2.6 and up */
+      case KSTAT_DATA_INT32:
+	*(Counter *)v = d->value.i32;
+	DEBUGMSGTL(("kernel_sunos5", "value: %d\n", d->value.i32));
+	break;
+      case KSTAT_DATA_UINT32:
+	*(Counter *)v = d->value.ui32;
+	DEBUGMSGTL(("kernel_sunos5", "value: %u\n", d->value.ui32));
+	break;
+      case KSTAT_DATA_INT64:
+	*(Counter *)v = d->value.i64;
+	DEBUGMSGTL(("kernel_sunos5", "value: %ld\n", d->value.i64));
+	break;
+      case KSTAT_DATA_UINT64:
+	*(Counter *)v = d->value.ui64;
+	DEBUGMSGTL(("kernel_sunos5", "value: %lu\n", d->value.ui64));
+	break;
+#else
       case KSTAT_DATA_LONG:
-	*(long *)v = d->value.l;
+	*(Counter *)v = d->value.l;
 	DEBUGMSGTL(("kernel_sunos5", "value: %ld\n", d->value.l));
 	break;
       case KSTAT_DATA_ULONG:
-	*(ulong_t *)v = d->value.ul;
+	*(Counter *)v = d->value.ul;
 	DEBUGMSGTL(("kernel_sunos5", "value: %lu\n", d->value.ul));
 	break;
-#if KSTAT_DATA_LONGLONG != KSTAT_DATA_LONG
       case KSTAT_DATA_LONGLONG:
-	*(longlong_t *)v = d->value.ll;
-	DEBUGMSGTL(("kernel_sunos5", "value: %ld\n", (long)d->value.ll));
+	*(Counter *)v = d->value.ll;
+	DEBUGMSGTL(("kernel_sunos5", "value: %lld\n", (long)d->value.ll));
 	break;
-#endif
-#if KSTAT_DATA_ULONGLONG != KSTAT_DATA_ULONG
       case KSTAT_DATA_ULONGLONG:
-	*(u_longlong_t *)v = d->value.ull;
-	DEBUGMSGTL(("kernel_sunos5", "value: %lu\n", (unsigned long)d->value.ul));
+	*(Counter *)v = d->value.ull;
+	DEBUGMSGTL(("kernel_sunos5", "value: %llu\n", (unsigned long)d->value.ull));
 	break;
 #endif
       case KSTAT_DATA_FLOAT:
@@ -283,8 +355,8 @@ getKstat(char *statname, char *varname, void *value)
         DEBUGMSGTL(("kernel_sunos5", "value: %f\n", d->value.d));
 	break;
       default:
-	fprintf(stderr, "Unknown type in kstat data: %s %s %d\n",
-		statname, varname, d->data_type);
+	DEBUGMSGTL(("kernel_sunos5", "Unknown type in kstat data: %s %s %d\n",
+		statname, varname, d->data_type));
 	ret = -3;
 	goto Return;		/* Invalid data type */
       }
@@ -294,8 +366,6 @@ getKstat(char *statname, char *varname, void *value)
   }
   ret = -4;			/* Name not found */
  Return:
-  if (ksc != NULL)
-    kstat_close(ksc);
   return (ret);
 }
 
@@ -308,10 +378,11 @@ getKstat(char *statname, char *varname, void *value)
  * If search is successful getMibstat returns 0, otherwise 1.
  */
 int
-getMibstat(mibgroup_e grid,  void *resp, int entrysize,
+getMibstat(mibgroup_e grid,  void *resp, size_t entrysize,
 	   req_e req_type, int (*comp)(void *, void *), void *arg)
 {
-    int		ret, rc=-1, mibgr, mibtb, cache_valid, length;
+    int		ret, rc=-1, mibgr, mibtb, cache_valid;
+    size_t	length;
     mibcache	*cachep;
     found_e	result = NOT_FOUND;
     void*	ep;
@@ -405,7 +476,7 @@ getMibstat(mibgroup_e grid,  void *resp, int entrysize,
  */
 
 static found_e
-getentry(req_e req_type, void *bufaddr, int len, int entrysize,
+getentry(req_e req_type, void *bufaddr, size_t len, size_t entrysize,
 	 void *resp, int (*comp)(void *, void *), void *arg)
 {     
     void *bp = bufaddr, **rp = resp;
@@ -475,8 +546,8 @@ init_mibcache_element(mibcache *cp)
    NOTE: needs to be protected by a mutex in reentrant environment */
 
 static int
-getmib(int groupname, int subgroupname, void *statbuf, size_t size, int entrysize,
-	   req_e req_type, void *resp, int *length, int (*comp)(void *, void *), void *arg)
+getmib(int groupname, int subgroupname, void *statbuf, size_t size, size_t entrysize,
+	   req_e req_type, void *resp, size_t *length, int (*comp)(void *, void *), void *arg)
 {
   int 		rc, ret = 0, flags;
   char		buf[BUFSIZE];
@@ -625,10 +696,10 @@ getmib(int groupname, int subgroupname, void *statbuf, size_t size, int entrysiz
  */
 static int
 getif(mib2_ifEntry_t *ifbuf, size_t size, req_e req_type,
-      mib2_ifEntry_t *resp, int *length, int (*comp)(void *, void *), void *arg)
+      mib2_ifEntry_t *resp, size_t *length, int (*comp)(void *, void *), void *arg)
 {
     int 		i, ret, idx = 1;
-    int 		sd;
+    int 		ifsd;
     char 		buf[10240];
     struct ifconf 	ifconf;
     struct ifreq 	*ifrp;
@@ -637,12 +708,12 @@ getif(mib2_ifEntry_t *ifbuf, size_t size, req_e req_type,
     int   		nentries = size/sizeof(mib2_ifEntry_t);
     found_e		result = NOT_FOUND;
 
-    if ((sd = socket(AF_INET, SOCK_DGRAM, 0)) < 0)
+    if ((ifsd = socket(AF_INET, SOCK_DGRAM, 0)) < 0)
 	return (-1);
     ifconf.ifc_buf = buf;
     ifconf.ifc_len = sizeof(buf);
-    if (ioctl(sd, SIOCGIFCONF, &ifconf) == -1) {
-	fprintf (stderr, "cannot SIOCGIFCONF - increase buffer size\n");
+    if (ioctl(ifsd, SIOCGIFCONF, &ifconf) == -1) {
+ snmp_log(LOG_ERR, "cannot SIOCGIFCONF - increase buffer size\n");
 	ret = -1;
 	goto Return;
     }
@@ -651,7 +722,7 @@ getif(mib2_ifEntry_t *ifbuf, size_t size, req_e req_type,
 	 ((char *)ifrp < ((char *)ifconf.ifc_buf + ifconf.ifc_len)) && (i < nentries);
 	 i++, ifp++, ifrp++, idx++) {
         DEBUGMSGTL(("kernel_sunos5", "...... getif %s\n", ifrp->ifr_name));
-	if (ioctl(sd, SIOCGIFFLAGS, ifrp) < 0) {
+	if (ioctl(ifsd, SIOCGIFFLAGS, ifrp) < 0) {
 	    ret = -1;
 	    DEBUGMSGTL(("kernel_sunos5", "...... SIOCGIFFLAGS failed\n"));
 	    goto Return;
@@ -663,7 +734,7 @@ getif(mib2_ifEntry_t *ifbuf, size_t size, req_e req_type,
 	ifp->ifAdminStatus = (ifrp->ifr_flags & IFF_RUNNING) ? 1 : 2;
 	ifp->ifOperStatus = (ifrp->ifr_flags & IFF_UP) ? 1 : 2;
 	ifp->ifLastChange = 0;		/* Who knows ...  */
-	if (ioctl(sd, SIOCGIFMTU, ifrp) < 0) {
+	if (ioctl(ifsd, SIOCGIFMTU, ifrp) < 0) {
 	    ret = -1;
 	    DEBUGMSGTL(("kernel_sunos5", "...... SIOCGIFMTU failed\n"));
 	    goto Return;
@@ -700,7 +771,7 @@ getif(mib2_ifEntry_t *ifbuf, size_t size, req_e req_type,
 		break;
 	}
 	if (!strchr (ifrp->ifr_name, ':')) {
-	    unsigned long l_tmp;
+	    Counter l_tmp;
 	    if (getKstat(ifrp->ifr_name, "ipackets", &ifp->ifInUcastPkts) < 0) {
 		ret = -1;
 		goto Return;
@@ -735,7 +806,7 @@ getif(mib2_ifEntry_t *ifbuf, size_t size, req_e req_type,
 	 * There should be a more elegant solution using DLPI, but
 	 * "the margin is too small to put it here ..."
 	 */
-	if (ioctl(sd, SIOCGIFADDR, ifrp) < 0) {
+	if (ioctl(ifsd, SIOCGIFADDR, ifrp) < 0) {
 	    ret = -1;
 	    goto Return;
 	}
@@ -769,7 +840,7 @@ getif(mib2_ifEntry_t *ifbuf, size_t size, req_e req_type,
 	*length = i * sizeof(mib2_ifEntry_t); /* Actual cache length */
     }
  Return:
-    close(sd);
+    close(ifsd);
     return (ret);	/* DONE */
 }
 
@@ -816,7 +887,7 @@ main (int argc, char **argv)
   u_long val = 0;
 
   if (argc != 3) {
-    fprintf(stderr, "Usage: %s stat_name var_name\n", argv[0]);
+    snmp_log(LOG_ERR, "Usage: %s stat_name var_name\n", argv[0]);
     exit(1);
   }
 
@@ -824,9 +895,9 @@ main (int argc, char **argv)
   rc = getKstat(argv[1], argv[2], &val);
 
   if (rc == 0)
-    fprintf(stderr, "%s = %lu\n", argv[2], val);
+    snmp_log(LOG_ERR, "%s = %lu\n", argv[2], val);
   else
-    fprintf(stderr, "rc =%d\n", rc);
+    snmp_log(LOG_ERR, "rc =%d\n", rc);
   return 0;
 }
 #endif /*_GETKSTAT_TEST */
@@ -844,9 +915,9 @@ ip20comp(void *ifname, void *ipp)
 int
 ARP_Cmp_Addr(void *addr, void *ep)
 {
-  fprintf(stderr, "ARP: %lx <> %lx\n",
+  DEBUGMSGTL(("kernel_sunos5", "ARP: %lx <> %lx\n",
       ((mib2_ipNetToMediaEntry_t *)ep)->ipNetToMediaNetAddress,
-      *(IpAddress *)addr);
+      *(IpAddress *)addr));
   if (((mib2_ipNetToMediaEntry_t *)ep)->ipNetToMediaNetAddress ==
       *(IpAddress *)addr)
     return (0);
@@ -873,7 +944,7 @@ main (int argc, char **argv)
   IpAddress		LastAddr = 0;
 
   if (argc != 3) {
-    fprintf(stderr, "Usage: %s if_name req_type (0 first, 1 exact, 2 next) \n",
+    snmp_log(LOG_ERR, "Usage: %s if_name req_type (0 first, 1 exact, 2 next) \n",
 	    argv[0]);
     exit(1);
   }
@@ -894,21 +965,21 @@ main (int argc, char **argv)
   while ((rc = getMibstat(MIB_INTERFACES, &ifstat, sizeof(mib2_ifEntry_t),
 			  req_type, &IF_cmp, &idx)) == 0) {
       idx = ifstat.ifIndex;
-      fprintf(stdout, "Ifname = %s\n", ifstat.ifDescr.o_bytes);
+      DEBUGMSGTL(("kernel_sunos5", "Ifname = %s\n", ifstat.ifDescr.o_bytes));
       req_type = GET_NEXT;
   }
   rc = getMibstat(MIB_IP_ADDR, &ipbuf, sizeof(mib2_ipAddrEntry_t),
 		  req_type, ip20comp, argv[1]); 
 
   if (rc == 0)
-    fprintf(stdout, "mtu = %ld\n", ipp->ipAdEntInfo.ae_mtu);
+    DEBUGMSGTL(("kernel_sunos5", "mtu = %ld\n", ipp->ipAdEntInfo.ae_mtu));
   else
-    fprintf(stderr, "rc =%d\n", rc);
+    DEBUGMSGTL(("kernel_sunos5", "rc =%d\n", rc));
 
   while ((rc = getMibstat(MIB_IP_NET, &entry, sizeof(mib2_ipNetToMediaEntry_t),
 			  req_type, &ARP_Cmp_Addr, &LastAddr)) == 0) {
     LastAddr = ep->ipNetToMediaNetAddress;
-    fprintf(stdout, "Ipaddr = %lX\n", (u_long)LastAddr);
+    DEBUGMSGTL(("kernel_sunos5", "Ipaddr = %lX\n", (u_long)LastAddr));
     req_type = GET_NEXT;
   }
   return 0;
