@@ -18,7 +18,7 @@
 #include <winsock.h>
 #endif
 
-#include "../mibincl.h"
+#include "mibincl.h"
 #include "system.h"
 #include "util_funcs.h"
 
