@@ -298,6 +298,10 @@ void vacm_parse_group (const char *token,
 	return;
     }
     gp = vacm_createGroupEntry(imodel, security);
+    if (!gp) {
+	config_perror("failed to create group entry");
+	return;
+    }
     strcpy (gp->groupName, group);
     gp->storageType = SNMP_STORAGE_PERMANENT;
     gp->status = SNMP_ROW_ACTIVE;
@@ -398,6 +402,10 @@ void vacm_parse_access (const char *token, char *param)
 	return;
     }
     ap = vacm_createAccessEntry (name, context, imodel, ilevel);
+    if (!ap) {
+	config_perror("failed to create access entry");
+	return;
+    }
     strcpy(ap->readView, readView);
     strcpy(ap->writeView, writeView);
     strcpy(ap->notifyView, notify);
@@ -424,7 +432,6 @@ void vacm_parse_view (const char *token,
     u_char viewMask[sizeof (vp->viewMask)];
     int i;
 
-    init_mib();
     name = strtok (param, " \t\n");
     if (!name) {
 	config_perror("missing NAME parameter");
@@ -474,6 +481,10 @@ void vacm_parse_view (const char *token,
 	    viewMask[i] = 0xff;
     }
     vp = vacm_createViewEntry(name, suboid, suboid_len);
+    if (!vp) {
+	config_perror("failed to create view entry");
+	return;
+    }
     memcpy(vp->viewMask, viewMask, sizeof(viewMask));
     vp->viewType = inclexcl;
     vp->viewStorageType = SNMP_STORAGE_PERMANENT;
@@ -640,7 +651,7 @@ int vacm_in_view (struct snmp_pdu *pdu,
 	}
 
 	/* allow running without snmpd.conf */
-	if (sp == NULL) {
+	if (sp == NULL && !vacm_is_configured()) {
 	    DEBUGMSGTL(("mibII/vacm_vars", "vacm_in_view: accepted with no com2sec entries\n"));
 	    switch (pdu->command) {
 	    case SNMP_MSG_GET:
