@@ -7,18 +7,22 @@
 
 config_require(util_funcs)
 config_add_mib(SNMP-VIEW-BASED-ACM-MIB) 
+config_add_mib(SNMP-COMMUNITY-MIB)
 
 void init_vacm_vars (void);
 void vacm_free_security (void);
 void vacm_free_group (void);
 void vacm_free_access (void);
 void vacm_free_view (void);
-void vacm_parse_security (char *, char *);
-void vacm_parse_group (char *, char *);
-void vacm_parse_access (char *, char *);
-void vacm_parse_view (char *, char *);
+void vacm_parse_security (const char *, char *);
+void vacm_parse_group (const char *, char *);
+void vacm_parse_access (const char *, char *);
+void vacm_parse_view (const char *, char *);
+void vacm_parse_simple (const char *, char *);
 
-int vacm_in_view (struct packet_info *, oid *, int);
+SNMPCallback vacm_in_view_callback;
+
+int vacm_in_view (struct snmp_pdu *, oid *, size_t);
 
 extern FindVarMethod var_vacm_sec2group;
 extern FindVarMethod var_vacm_access;
