@@ -1,4 +1,7 @@
 #include <config.h>
+#if HAVE_STDLIB_H
+#include <stdlib.h>
+#endif
 
 #include <sys/types.h>
 #include <sys/stat.h>
