@@ -44,7 +44,7 @@ void init_versioninfo(void)
     {VERCDATE, ASN_OCTET_STR, RONLY, var_extensible_version, 1, {VERCDATE}},
     {VERIDENT, ASN_OCTET_STR, RONLY, var_extensible_version, 1, {VERIDENT}},
     {VERCONFIG, ASN_OCTET_STR, RONLY, var_extensible_version, 1, {VERCONFIG}},
-    {VERCLEARCACHE, ASN_INTEGER, RONLY, var_extensible_version, 1, {VERCLEARCACHE}},
+    {VERCLEARCACHE, ASN_INTEGER, RWRITE, var_extensible_version, 1, {VERCLEARCACHE}},
     {VERUPDATECONFIG, ASN_INTEGER, RWRITE, var_extensible_version, 1, {VERUPDATECONFIG}},
     {VERRESTARTAGENT, ASN_INTEGER, RWRITE, var_extensible_version, 1, {VERRESTARTAGENT}},
     {VERDEBUGGING, ASN_INTEGER, RWRITE, var_extensible_version, 1, {VERDEBUGGING}}
@@ -93,17 +93,17 @@ u_char *var_extensible_version(struct variable *vp,
       *var_len = strlen(errmsg);
       return((u_char *) errmsg); 
     case VERDATE:
-      sprintf(errmsg,"$Date: 2000/01/13 05:09:40 $");
+      sprintf(errmsg,"$Date: 2000/04/14 16:04:07 $");
       *var_len = strlen(errmsg);
       return((u_char *) errmsg); 
     case VERCDATE:
       curtime = time(NULL);
       cptr = ctime(&curtime);
       sprintf(errmsg,cptr);
-      *var_len = strlen(errmsg);
+      *var_len = strlen(errmsg)-1;
       return((u_char *) errmsg);
     case VERIDENT:
-      sprintf(errmsg,"$Id: versioninfo.c,v 1.18 2000/01/13 05:09:40 mslifcak Exp $");
+      sprintf(errmsg,"$Id: versioninfo.c,v 1.18.2.2 2000/04/14 16:04:07 hardaker Exp $");
       *var_len = strlen(errmsg);
       return((u_char *) errmsg);
     case VERCONFIG:
