@@ -2,6 +2,7 @@
 config_require(ucd-snmp/proc)
 config_require(ucd-snmp/versioninfo)
 config_require(ucd-snmp/pass)
+config_require(ucd-snmp/pass_persist)
 config_require(ucd-snmp/disk)
 config_require(ucd-snmp/loadave)
 config_require(ucd-snmp/extensible)
@@ -20,7 +21,11 @@ config_arch_require(bsdi3, ucd-snmp/memory)
 config_arch_require(linux, ucd-snmp/vmstat)
 config_arch_require(freebsd2, ucd-snmp/vmstat_freebsd2)
 config_arch_require(freebsd2, ucd-snmp/memory_freebsd2)
+config_arch_require(freebsd3, ucd-snmp/vmstat_freebsd2)
+config_arch_require(freebsd3, ucd-snmp/memory_freebsd2)
 config_arch_require(freebsd4, ucd-snmp/vmstat_freebsd2)
 config_arch_require(freebsd4, ucd-snmp/memory_freebsd2)
+config_arch_require(netbsd1, ucd-snmp/vmstat_netbsd1)
+config_arch_require(netbsd1, ucd-snmp/memory_netbsd1)
 config_add_mib(UCD-SNMP-MIB) 
 config_add_mib(UCD-DEMO-MIB) 
