@@ -1,5 +1,12 @@
+/*
+ * util_funcs.c
+ */
+
 #include <config.h>
 
+#if HAVE_IO_H
+#include <io.h>
+#endif
 #include <stdio.h>
 #if HAVE_STDLIB_H
 #include <stdlib.h>
@@ -30,7 +37,11 @@
 # define WIFEXITED(stat_val) (((stat_val) & 255) == 0)
 #endif
 #if TIME_WITH_SYS_TIME
-# include <sys/time.h>
+# ifdef WIN32
+#  include <sys/timeb.h>
+# else
+#  include <sys/time.h>
+# endif
 # include <time.h>
 #else
 # if HAVE_SYS_TIME_H
@@ -53,18 +64,29 @@
 #include <strings.h>
 #endif
 #include <ctype.h>
-
+#if HAVE_WINSOCK_H
+#include <winsock.h>
+#endif
+#if HAVE_BASETSD_H
+#include <basetsd.h>
+#define ssize_t SSIZE_T
+#endif
+#if HAVE_RAISE
+#define alarm raise
+#endif
 #include "mibincl.h"
 #include "struct.h"
 #include "util_funcs.h"
 #include "../../snmplib/system.h"
+#if HAVE_LIMITS_H
+#include "limits.h"
+#endif
 #ifdef USING_UCD_SNMP_ERRORMIB_MODULE
 #include "ucd-snmp/errormib.h"
 #else
-#define setPerrorstatus(x) perror(x)
+#define setPerrorstatus(x) snmp_log_perror(x)
 #endif
 #include "read_config.h"
-#include "mib_module_config.h"
 
 #ifdef EXCACHETIME
 static long cachetime;
@@ -75,13 +97,13 @@ extern int numprocs, numextens;
 void
 Exit(int var)
 {
-  fprintf(stderr, "Server Exiting with code %d\n",var);
-  fclose (stderr);
+  snmp_log(LOG_ERR, "Server Exiting with code %d\n",var);
   exit(var);
 }
 
 int shell_command(struct extensible *ex)
 {
+#if HAVE_SYSTEM
   char shellline[STRMAX];
   FILE *shellout;
   
@@ -96,6 +118,10 @@ int shell_command(struct extensible *ex)
     fclose(shellout);
   }
   unlink("/tmp/shoutput");
+#else
+  ex->output[0] = 0;
+  ex->result = 0;
+#endif
   return(ex->result);
 }
 
@@ -103,19 +129,20 @@ int shell_command(struct extensible *ex)
 
 int exec_command(struct extensible *ex)
 {
+#if HAVE_EXECV
   int fd;
   FILE *file;
   
   if ((fd = get_exec_output(ex))) {
-    
     file = fdopen(fd,"r");
     if (fgets(ex->output,STRMAX,file) == NULL) {
       ex->output[0] = 0;
     }
     fclose(file);
-    close(fd);
     wait_on_exec(ex);
-  } else {
+  } else
+#endif
+  {
     ex->output[0] = 0;
     ex->result = 0;
   }
@@ -136,11 +163,12 @@ void wait_on_exec(struct extensible *ex)
 
 int get_exec_output(struct extensible *ex)
 {
+#if HAVE_EXECV
   int fd[2],i, cnt;
   char ctmp[STRMAX], *cptr1, *cptr2, argvs[STRMAX], **argv, **aptr;
 #ifdef EXCACHETIME
   char cache[MAXCACHESIZE];
-  long cachebytes;
+  ssize_t cachebytes;
   long curtime;
   static char lastcmd[STRMAX];
   int cfd;
@@ -186,6 +214,8 @@ int get_exec_output(struct extensible *ex)
         *cptr2 = 0;
         *(cptr2+1) = 0;
         argv = (char **) malloc((cnt+2) * sizeof(char *));
+        if (argv == NULL)
+          return 0; /* memory alloc error */
         aptr = argv;
         *(aptr++) = argvs;
         for (cptr2 = argvs, i=1; i != cnt; cptr2++)
@@ -197,7 +227,7 @@ int get_exec_output(struct extensible *ex)
         *(aptr++) = NULL;
         copy_word(ex->command,ctmp);
         execv(ctmp,argv);
-        perror(ctmp);
+        snmp_log_perror(ctmp);
         exit(1);
       }
     else
@@ -213,6 +243,7 @@ int get_exec_output(struct extensible *ex)
         }
 #ifdef EXCACHETIME
         unlink(CACHEFILE);
+	/* XXX  Use SNMP_FILEMODE_CLOSED instead of 644? */
         if ((cfd = open(CACHEFILE,O_WRONLY|O_TRUNC|O_CREAT,0644)) < 0) {
           setPerrorstatus("open");
           cachetime = 0;
@@ -252,7 +283,7 @@ int get_exec_output(struct extensible *ex)
         ex->pid = 0;
         ex->result = WEXITSTATUS(ex->result);
         lastresult = ex->result;
-#else
+#else /* !EXCACHETIME */
         return(fd[0]);
 #endif
       }
@@ -267,6 +298,10 @@ int get_exec_output(struct extensible *ex)
   }
   return(cfd);
 #endif
+
+#else /* !HAVE_EXECV */
+  return 0;
+#endif
 }
 
 int get_exec_pipes(char *cmd,
@@ -275,6 +310,7 @@ int get_exec_pipes(char *cmd,
 		   int *pid)
 
 {
+#if HAVE_EXECV
   int fd[2][2],i, cnt;
   char ctmp[STRMAX], *cptr1, *cptr2, argvs[STRMAX], **argv, **aptr;
   /* Setup our pipes */
@@ -314,6 +350,8 @@ int get_exec_pipes(char *cmd,
       *cptr2 = 0;
       *(cptr2+1) = 0;
       argv = (char **) malloc((cnt+2) * sizeof(char *));
+      if (argv == NULL)
+        return 0; /* memory alloc error */
       aptr = argv;
       *(aptr++) = argvs;
       for (cptr2 = argvs, i=1; i != cnt; cptr2++)
@@ -325,7 +363,7 @@ int get_exec_pipes(char *cmd,
       *(aptr++) = NULL;
       copy_word(cmd,ctmp);
       execv(ctmp,argv);
-      perror("execv");
+      snmp_log_perror("execv");
       exit(1);
     }
   else
@@ -342,25 +380,26 @@ int get_exec_pipes(char *cmd,
       *fdOut = fd[0][1];
       return(1); /* We are returning 0 for error... */
     }
+#endif /* !HAVE_EXECV */
+  return 0;
 }
 
 int clear_cache(int action,
 		u_char *var_val,
 		u_char var_val_type,
-		int var_val_len,
+		size_t var_val_len,
 		u_char *statP,
 		oid *name,
-		int name_len)
+		size_t name_len)
 {
   
   long tmp=0;
-  int tmplen=1000;
 
   if (var_val_type != ASN_INTEGER) {
-    printf("Wrong type != int\n");
+    snmp_log(LOG_NOTICE, "Wrong type != int\n");
     return SNMP_ERR_WRONGTYPE;
   }
-  asn_parse_int(var_val,&tmplen,&var_val_type,&tmp,sizeof(int));
+  tmp = *((long *) var_val);
   if (tmp == 1 && action == COMMIT) {
 #ifdef EXCACHETIME
     cachetime = 0;                      /* reset the cache next read */
@@ -369,7 +408,7 @@ int clear_cache(int action,
   return SNMP_ERR_NOERROR;
 }
 
-extern char **argvrestartp, *argvrestartname;
+char **argvrestartp, *argvrestartname, *argvrestart;
 
 RETSIGTYPE restart_doit(int a)
 {
@@ -380,30 +419,33 @@ RETSIGTYPE restart_doit(int a)
     close(i);
 
   /* do the exec */
+#if HAVE_EXECV
   execv(argvrestartname,argvrestartp);
   setPerrorstatus("execv");
+#endif
 }
 
 int
 restart_hook(int action,
 	     u_char *var_val,
 	     u_char var_val_type,
-	     int var_val_len,
+	     size_t var_val_len,
 	     u_char *statP,
 	     oid *name,
-	     int name_len)
+	     size_t name_len)
 {
   
   long tmp=0;
-  int tmplen=1000;
 
   if (var_val_type != ASN_INTEGER) {
-    printf("Wrong type != int\n");
+    snmp_log(LOG_NOTICE, "Wrong type != int\n");
     return SNMP_ERR_WRONGTYPE;
   }
-  asn_parse_int(var_val,&tmplen,&var_val_type,&tmp,sizeof(int));
+  tmp = *((long *) var_val);
   if (tmp == 1 && action == COMMIT) {
+#ifdef SIGALRM
     signal(SIGALRM,restart_doit);
+#endif
     alarm(RESTARTSLEEP);
   } 
   return SNMP_ERR_NOERROR;
@@ -411,33 +453,68 @@ restart_hook(int action,
 
 void
 print_mib_oid(oid name[],
-	      int len)
+	      size_t len)
 {
-  int i;
-  printf("Mib:  ");
-  for(i=0; i < len; i++) {
-    printf(".%d",(int) name[i]);
+  char *buffer;
+  buffer=malloc(11*len); /* maximum digit lengths for int32 + a '.' */
+  if (!buffer) {
+    snmp_log(LOG_ERR, "Malloc failed - out of memory?");
+    return;
   }
+  sprint_mib_oid(buffer, name, len);
+  snmp_log(LOG_NOTICE, "Mib: %s\n", buffer);
+  free(buffer);
 }
 
 void
 sprint_mib_oid(char *buf,
 	       oid name[],
-	       int len)
+	       size_t len)
 {
   int i;
-  for(i=0; i < len; i++) {
+  for(i=0; i < (int)len; i++) {
     sprintf(buf,".%d",(int) name[i]);
     while (*buf != 0)
       buf++;
   }
 }
 
-int header_simple_table(struct variable *vp, oid *name, int *length,
-                        int exact, int *var_len,
+/*******************************************************************-o-******
+ * header_simple_table
+ *
+ * Parameters:
+ *	  *vp		 Variable data.
+ *	  *name		 Fully instantiated OID name.
+ *	  *length	 Length of name.
+ *	   exact	 TRUE if an exact match is desired.
+ *	  *var_len	 Hook for size of returned data type.
+ *	(**write_method) Hook for write method (UNUSED).
+ *	   max
+ *      
+ * Returns:
+ *	0	If name matches vp->name (accounting for 'exact') and is
+ *			not greater in length than 'max'.
+ *	1	Otherwise.
+ *
+ *
+ * Compare 'name' to vp->name for the best match or an exact match (if
+ *	requested).  Also check that 'name' is not longer than 'max' if
+ *	max is greater-than/equal 0.
+ * Store a successful match in 'name', and increment the OID instance if
+ *	the match was not exact.  
+ *
+ * 'name' and 'length' are undefined upon failure.
+ *
+ */
+int header_simple_table(struct variable *vp, oid *name, size_t *length,
+                        int exact, size_t *var_len,
                         WriteMethod **write_method, int max)
 {
-  int i, rtest;
+  int	i,
+	rtest;	/* Set to:	-1	If name < vp->name,
+	 	 *		1	If name > vp->name,
+		 *		0	Otherwise.
+		 */
   oid newname[MAX_OID_LEN];
 
   for(i=0,rtest=0; i < (int) vp->namelen && i < (int)(*length) && !rtest; i++) {
@@ -449,15 +526,15 @@ int header_simple_table(struct variable *vp, oid *name, int *length,
     }
   }
   if (rtest > 0 ||
-      (rtest == 0 && !exact && (int) vp->namelen+1 < (int) *length) ||
-    (exact == 1 && (rtest || *length != vp->namelen+1))) {
+      (rtest == 0 && !exact && (int)(vp->namelen+1) < (int) *length) ||
+    (exact == 1 && (rtest || (int)*length != (int)(vp->namelen+1)))) {
     if (var_len)
 	*var_len = 0;
     return MATCH_FAILED;
   }
-/*  printf("%d/ck:  vp=%d  ln=%d lst=%d\n",exact,
-         vp->namelen,*length,name[*length-1]); */
+
   memset(newname, 0, sizeof(newname));
+
   if (((int) *length) <= (int) vp->namelen || rtest == -1) {
     memmove(newname, vp->name, (int)vp->namelen * sizeof (oid));
     newname[vp->namelen] = 1;
@@ -471,11 +548,12 @@ int header_simple_table(struct variable *vp, oid *name, int *length,
     else
       newname[*length-1] = name[*length-1];
   }  
-  if (max >= 0 && newname[*length-1] > max) {
+  if (max >= 0 && ((int)newname[*length-1] > max)) {
     if(var_len)
       *var_len = 0;
     return MATCH_FAILED;
   }
+
   memmove(name, newname, (*length) * sizeof(oid)); 
   if (write_method)
     *write_method = 0;
@@ -496,26 +574,42 @@ int header_simple_table(struct variable *vp, oid *name, int *length,
   
 */
 
+/*******************************************************************-o-******
+ * generic_header
+ *
+ * Parameters:
+ *	  *vp	   (I)     Pointer to variable entry that points here.
+ *	  *name	   (I/O)   Input name requested, output name found.
+ *	  *length  (I/O)   Length of input and output oid's.
+ *	   exact   (I)     TRUE if an exact match was requested.
+ *	  *var_len (O)     Length of variable or 0 if function returned.
+ *	(**write_method)   Hook to name a write method (UNUSED).
+ *      
+ * Returns:
+ *	MATCH_SUCCEEDED	If vp->name matches name (accounting for exact bit).
+ *	MATCH_FAILED	Otherwise,
+ *
+ *
+ * Check whether variable (vp) matches name.
+ */
 int
 header_generic(struct variable *vp,
 	       oid *name,
-	       int *length,
+	       size_t *length,
 	       int exact,
-	       int *var_len,
+	       size_t *var_len,
 	       WriteMethod **write_method)
 {
     oid newname[MAX_OID_LEN];
     int result;
-    char c_oid[SPRINT_MAX_LEN];
 
-    if (snmp_get_do_debugging()) {
-      sprint_objid (c_oid, name, *length);
-      DEBUGMSGTL(("util_funcs", "header_generic: %s exact=%d\n", c_oid, exact));
-    }
+    DEBUGMSGTL(("util_funcs", "header_generic: "));
+    DEBUGMSGOID(("util_funcs", name, *length));
+    DEBUGMSG(("util_funcs"," exact=%d\n", exact));
 
     memcpy((char *)newname, (char *)vp->name, (int)vp->namelen * sizeof(oid));
     newname[vp->namelen] = 0;
-    result = snmp_oid_compare(name, *length, newname, (int)vp->namelen + 1);
+    result = snmp_oid_compare(name, *length, newname, vp->namelen + 1);
     DEBUGMSGTL(("util_funcs", "  result: %d\n", result));
     if ((exact && (result != 0)) || (!exact && (result >= 0)))
         return(MATCH_FAILED);
@@ -528,8 +622,8 @@ header_generic(struct variable *vp,
 }
 
 /* checkmib(): provided for backwards compatibility, do not use: */
-int checkmib(struct variable *vp, oid *name, int *length,
-             int exact, int *var_len,
+int checkmib(struct variable *vp, oid *name, size_t *length,
+             int exact, size_t *var_len,
              WriteMethod **write_method, int max) {
   /* checkmib used to be header_simple_table, with reveresed boolean
      return output.  header_simple_table() was created to match
@@ -567,7 +661,7 @@ char *find_field(char *ptr,
   return(NULL);
 }
 
-int parse_miboid(char *buf,
+int parse_miboid(const char *buf,
 		 oid *oidout)
 {
   int i;
@@ -599,20 +693,3 @@ string_append_int (char *s,
     strcpy(s, textVal);
     return;
 }
-
-int
-calculate_time_diff(struct timeval t1,
-		    struct timeval t2)
-{
-  struct timeval tmp, diff;
-  memcpy(&tmp, &t1, sizeof(struct timeval));
-  tmp.tv_sec--;
-  tmp.tv_usec += 1000000L;
-  diff.tv_sec = tmp.tv_sec - t2.tv_sec;
-  diff.tv_usec = tmp.tv_usec - t2.tv_usec;
-  if (diff.tv_usec > 1000000L){
-    diff.tv_usec -= 1000000L;
-    diff.tv_sec++;
-  }
-  return ((diff.tv_sec * 100) + (diff.tv_usec / 10000));
-}
