@@ -61,7 +61,8 @@ SOFTWARE.
 #include <stdio.h>
 #if HAVE_WINSOCK_H
 #include <winsock.h>
-#else
+#endif
+#if HAVE_NETDB_H
 #include <netdb.h>
 #endif
 #if HAVE_ARPA_INET_H
@@ -82,7 +83,7 @@ oid objid_mib[] = {1, 3, 6, 1, 2, 1};
 void
 usage (void)
 {
-  fprintf(stderr,"Usage:\n  snmpbulkwalk ");
+  fprintf(stderr,"Usage: snmpbulkwalk ");
   snmp_parse_args_usage(stderr);
   fprintf(stderr," [<objectID>]\n\n");
   snmp_parse_args_descriptions(stderr);
@@ -96,23 +97,23 @@ int main(int argc, char  *argv[])
     struct variable_list *vars;
     int  arg;
     oid  name[MAX_OID_LEN];
-    int  name_length;
+    size_t  name_length;
     oid  root[MAX_OID_LEN];
-    int  rootlen;
+    size_t  rootlen;
     int  count;
     int  running;
     int  status;
     int  reps = 1000;
 
     /* get the common command line arguments */
-    arg = snmp_parse_args(argc, argv, &session);
+    arg = snmp_parse_args(argc, argv, &session, NULL, NULL);
 
     /* get the initial object and subtree */
     if (arg < argc) {
       /* specified on the command line */
       rootlen = MAX_OID_LEN;
       if (snmp_parse_oid(argv[arg], root, &rootlen) == NULL) {
-        fprintf(stderr, "Invalid object identifier: %s\n", argv[arg]);
+        snmp_perror(argv[arg]);
         exit(1);
       }
     } else {
@@ -124,10 +125,10 @@ int main(int argc, char  *argv[])
     SOCK_STARTUP;
 
     /* open an SNMP session */
-    snmp_synch_setup(&session);
     ss = snmp_open(&session);
     if (ss == NULL){
-      snmp_perror("snmpbulkwalk");
+      /* diagnose snmp_open errors with the input struct snmp_session pointer */
+      snmp_sess_perror("snmpbulkwalk", &session);
       SOCK_CLEANUP;
       exit(1);
     }
@@ -193,7 +194,7 @@ int main(int argc, char  *argv[])
         fprintf(stderr, "Timeout: No Response from %s\n", session.peername);
         running = 0;
       } else {    /* status == STAT_ERROR */
-        snmp_perror("snmpbulkwalk");
+        snmp_sess_perror("snmpbulkwalk", ss);
         running = 0;
       }
 
@@ -203,5 +204,5 @@ int main(int argc, char  *argv[])
 
     snmp_close(ss);
     SOCK_CLEANUP;
-    exit (0);
+    return 0;
 }
