@@ -1,6 +1,8 @@
 /*
  * snmptest.c - send snmp requests to a network entity.
  *
+ * Usage: snmptest -v 1 [-q] hostname community [objectID]
+ *
  */
 /***********************************************************************
 	Copyright 1988, 1989, 1991, 1992 by Carnegie Mellon University
@@ -61,7 +63,8 @@ SOFTWARE.
 #endif
 #if HAVE_WINSOCK_H
 #include <winsock.h>
-#else
+#endif
+#if HAVE_NETDB_H
 #include <netdb.h>
 #endif
 #if HAVE_ARPA_INET_H
@@ -76,6 +79,7 @@ SOFTWARE.
 #include "snmp.h"
 #include "system.h"
 #include "snmp_parse_args.h"
+#include "default_store.h"
 
 int command = SNMP_MSG_GET;
 
@@ -83,7 +87,7 @@ int input_variable (struct variable_list *);
 
 void usage(void)
 {
-  fprintf(stderr,"Usage:\n  snmptest ");
+  fprintf(stderr,"Usage: snmptest ");
   snmp_parse_args_usage(stderr);
   fprintf(stderr,"\n\n");
   snmp_parse_args_descriptions(stderr);
@@ -93,25 +97,23 @@ int main(int argc, char *argv[])
 {
     struct snmp_session session, *ss;
     struct snmp_pdu *pdu = NULL, *response, *copy = NULL;
+    struct sockaddr_in *respIp;
     struct variable_list *vars, *vp;
     int	ret;
     int	    status, count;
     char	input[128];
     int varcount, nonRepeaters = -1, maxRepetitions;
 
-    /* Usage: snmptest -v 1 [-q] hostname community [objectID]      or:
-     * Usage: snmptest [-v 2] [-q] hostname noAuth [objectID]       or:
-     * Usage: snmptest [-v 2] [-q] hostname srcParty dstParty context [objectID]
-     */
-
-    snmp_parse_args(argc, argv, &session);
+    /* get the common command line arguments */
+    snmp_parse_args(argc, argv, &session, NULL, NULL);
 
     SOCK_STARTUP;
 
-    snmp_synch_setup(&session);
+    /* open an SNMP session */
     ss = snmp_open(&session);
     if (ss == NULL){
-        snmp_perror("snmptest");
+      /* diagnose snmp_open errors with the input struct snmp_session pointer */
+        snmp_sess_perror("snmptest", &session);
         SOCK_CLEANUP;
 	exit(1);
     }
@@ -175,7 +177,7 @@ int main(int argc, char *argv[])
 	if (command == SNMP_MSG_TRAP2){
 	    /* No response needed */
 	    if (!snmp_send(ss, pdu)){
-                snmp_perror("snmptest");
+                snmp_sess_perror("snmptest", ss);
 	    }
 	} else {
 	    status = snmp_synch_response(ss, pdu, &response);
@@ -210,7 +212,8 @@ int main(int argc, char *argv[])
 			printf("Received SNMPv2 Trap Request ");
 			break;
 		    }
-		    printf("from %s\n", inet_ntoa(response->address.sin_addr));
+		    respIp = (struct sockaddr_in *)&(response->address);
+		    printf("from %s\n", inet_ntoa(respIp->sin_addr));
 		    printf("requestid 0x%lX errstat 0x%lX errindex 0x%lX\n",
 			   response->reqid, response->errstat,
 			   response->errindex);
@@ -238,7 +241,7 @@ int main(int argc, char *argv[])
 	    } else if (status == STAT_TIMEOUT){
 		printf("Timeout: No Response from %s\n", session.peername);
 	    } else {    /* status == STAT_ERROR */
-              snmp_perror("snmptest");
+              snmp_sess_perror("snmptest", ss);
 	    }
 
 	    if (response)
@@ -255,6 +258,7 @@ int
 input_variable(struct variable_list *vp)
 {
     char  buf[256];
+    int val_len;
     u_char value[256], ch;
     oid name[MAX_OID_LEN];
 
@@ -370,6 +374,7 @@ input_variable(struct variable_list *vp)
 		printf("bad type \"%c\", use \"i\", \"s\", \"x\", \"d\", \"n\", \"o\", \"t\", or \"a\".\n", *buf);
 		return -1;
 	}
+getValue:
 	printf("Value: "); fflush(stdout);
 	fgets(buf, sizeof(buf), stdin);
 	switch(vp->type){
@@ -380,12 +385,22 @@ input_variable(struct variable_list *vp)
 		break;
 	    case ASN_OCTET_STR:
 		if (ch == 'd'){
-		    vp->val_len = ascii_to_binary((u_char *)buf, value);
+		    val_len = ascii_to_binary(buf, value);
+		    if (vp->val_len < 0) {
+			printf("Bad value or no sub-identifier > 255\n");
+			goto getValue;
+		    }
+		    vp->val_len = val_len;
 		} else if (ch == 's'){
 		    strcpy((char*)value, buf);
 		    vp->val_len = strlen(buf);
 		} else if (ch == 'x'){
-		    vp->val_len = hex_to_binary((u_char *)buf, value);
+		    val_len = hex_to_binary(buf, value);
+		    if (vp->val_len < 0) {
+			printf("Bad value (need pairs of hex digits)\n");
+			goto getValue;
+		    }
+		    vp->val_len = val_len;
 		}
 		vp->val.string = (u_char *)malloc(vp->val_len);
 		memmove(vp->val.string, value, vp->val_len);
