@@ -101,15 +101,17 @@ SOFTWARE.
 #include "read_config.h"
 #include "snmp_debug.h"
 #include "snmp_logging.h"
+#include "callback.h"
 #include "snmpusm.h"
 #include "tools.h"
 #include "lcd_time.h"
 #include "transform_oids.h"
 #include "snmpv3.h"
-#include "callback.h"
 #include "snmp_alarm.h"
 #include "default_store.h"
 
+#define DS_APP_NUMERIC_IP  1
+
 #ifndef BSD4_3
 #define BSD4_2
 #endif
@@ -434,6 +436,9 @@ int snmp_input(int op,
 	    oid trapOid[MAX_OID_LEN];
 	    int trapOidLen = pdu->enterprise_length;
 	    struct sockaddr_in *agentIp = (struct sockaddr_in *)&pdu->agent_addr;
+		if( ds_get_boolean(DS_APPLICATION_ID, DS_APP_NUMERIC_IP) )
+			host = NULL;
+		else
 	    host = gethostbyaddr ((char *)&agentIp->sin_addr,
 				  sizeof (agentIp->sin_addr), AF_INET);
 	    if (pdu->trap_type == SNMP_TRAP_ENTERPRISESPECIFIC) {
@@ -450,6 +455,9 @@ int snmp_input(int op,
                        host ? host->h_name : inet_ntoa(agentIp->sin_addr),
                        inet_ntoa(agentIp->sin_addr));
 		if (agentIp->sin_addr.s_addr != pduIp->sin_addr.s_addr) {
+			if( ds_get_boolean(DS_APPLICATION_ID, DS_APP_NUMERIC_IP) )
+				host = NULL;
+			else
 		    host = gethostbyaddr ((char *)&pduIp->sin_addr,
 					  sizeof (pduIp->sin_addr), AF_INET);
 		    printf("(via %s [%s]) ",
@@ -522,6 +530,9 @@ int snmp_input(int op,
 		do_external(Command, host, pdu);
 	} else if (pdu->command == SNMP_MSG_TRAP2
 		   || pdu->command == SNMP_MSG_INFORM){
+		if( ds_get_boolean(DS_APPLICATION_ID, DS_APP_NUMERIC_IP) )
+			host = NULL;
+		else
 	    host = gethostbyaddr ((char *)&pduIp->sin_addr,
 				  sizeof (pduIp->sin_addr), AF_INET);
 	    if (Print) {
@@ -556,6 +567,9 @@ int snmp_input(int op,
 	    	if ( varbufidx ) {
 		    varbufidx -= 2; varbuf[varbufidx]='\0';
 	    	}
+		if( ds_get_boolean(DS_APPLICATION_ID, DS_APP_NUMERIC_IP) )
+			host = NULL;
+		else
 		host = gethostbyaddr ((char *)&pduIp->sin_addr,
 				      sizeof (pduIp->sin_addr), AF_INET);
 		syslog(LOG_WARNING, "%s [%s]: Trap %s",
@@ -586,6 +600,7 @@ int snmp_input(int op,
 		reply->address = pdu->address;
 		if (!snmp_send(session, reply)){
                     snmp_sess_perror("snmptrapd: Couldn't respond to inform pdu", session);
+		    snmp_free_pdu(reply);
 		}
 	    }
 	}
@@ -598,9 +613,9 @@ int snmp_input(int op,
 
 void usage(void)
 {
-    fprintf(stderr,"Usage: snmptrapd [-h|-H|-V] [-D] [-p #] [-P] [-s] [-f] [-l [d0-7]] [-e] [-d] [-a] [-m <MIBS>] [-M <MIBDIRS]\n");
+    fprintf(stderr,"Usage: snmptrapd [-h|-H|-V] [-D] [-p #] [-P] [-s] [-f] [-l [d0-7]] [-e] [-d] [-n] [-a] [-m <MIBS>] [-M <MIBDIRS]\n");
     fprintf(stderr,"UCD-snmp version: %s\n", VersionInfo);
-    fprintf(stderr, "\
+    fprintf(stderr, "\n\
   -h        Print this help message and exit\n\
   -H        Read what can show up in config file\n\
   -V        Print version and exit\n\
@@ -614,6 +629,7 @@ void usage(void)
   -f        Stay in foreground (don't fork)\n\
   -l [d0-7 ]  Set syslog Facility to log daemon[d], log local 0(default) [1-7]\n\
   -d        Dump input/output packets\n\
+  -n        Use numeric IP addresses instead of host names (no DNS)\n\
   -a        Ignore Authentication Failture traps.\n\
   -c CONFFILE Read CONFFILE as a configuration file.\n\
   -C        Don't read the default configuration files.\n\
@@ -636,11 +652,9 @@ RETSIGTYPE hup_handler(int sig)
 }
 #endif
 
-
 int main(int argc, char *argv[])
 {
     struct snmp_session sess, *session = &sess, *ss;
-    struct usmUser *user, *userListPtr;
     int	arg;
     int count, numfds, block;
     fd_set fdset;
@@ -667,6 +681,12 @@ int main(int argc, char *argv[])
     register_config_handler("snmptrapd", "createUser",
 			    usm_parse_create_usmUser, NULL,
 			    "username (MD5|SHA) passphrase [DES passphrase]");
+    register_config_handler("snmptrapd", "usmUser",
+                            usm_parse_config_usmUser, NULL, NULL);
+
+  /* we need to be called back later */
+  snmp_register_callback(SNMP_CALLBACK_LIBRARY, SNMP_CALLBACK_STORE_DATA,
+                         usm_store_users, NULL);
 
 #ifdef WIN32
     setvbuf (stdout, NULL, _IONBF, BUFSIZ);
@@ -676,7 +696,7 @@ int main(int argc, char *argv[])
     /*
      * usage: snmptrapd [-D] [-u PIDFILE] [-p #] [-P] [-s] [-l [d0-7]] [-d] [-e] [-a]
      */
-    while ((arg = getopt(argc, argv, "VdqRD:p:m:M:PO:esSafl:Hu:c:C")) != EOF){
+    while ((arg = getopt(argc, argv, "VdnqRD:p:m:M:PO:esSafl:Hu:c:C")) != EOF){
 	switch(arg) {
 	case 'V':
             fprintf(stderr,"UCD-snmp version: %s\n", VersionInfo);
@@ -774,6 +794,10 @@ int main(int argc, char *argv[])
             ds_set_boolean(DS_LIBRARY_ID, DS_LIB_DONT_READ_CONFIGS, 1);
             break;
 
+        case 'n':
+            ds_set_boolean(DS_APPLICATION_ID, DS_APP_NUMERIC_IP, 1);
+            break;
+
 	default:
 	    fprintf(stderr,"invalid option: -%c\n", arg);
 	    usage();
@@ -944,6 +968,7 @@ int main(int argc, char *argv[])
 	syslog(LOG_INFO, "Stopping snmptrapd");
 
     snmp_close(ss);
+    snmp_shutdown("snmptrapd");
     SOCK_CLEANUP;
     return 0;
 }
