@@ -51,6 +51,7 @@
 #include "system.h"
 #include "asn1.h"
 #include "snmpv3.h"
+#include "callback.h"
 #include "snmpusm.h"
 #include "snmp.h"
 #include "snmp_api.h"
@@ -63,7 +64,6 @@
 #include "lcd_time.h"
 #include "snmp_debug.h"
 #include "snmp_logging.h"
-#include "callback.h"
 #include "default_store.h"
 
 #include "transform_oids.h"
@@ -86,12 +86,12 @@ static size_t	 defaultPrivTypeLen	= 0;
 void
 snmpv3_authtype_conf(const char *word, char *cptr)
 {
-  if (strcmp(cptr,"MD5") == 0)
+  if (strcasecmp(cptr,"MD5") == 0)
     defaultAuthType = usmHMACMD5AuthProtocol;
-  else if (strcmp(cptr,"SHA") == 0)
+  else if (strcasecmp(cptr,"SHA") == 0)
     defaultAuthType = usmHMACMD5AuthProtocol;
   else
-    config_perror("unknown authentication type");
+    config_perror("Unknown authentication type");
   defaultAuthTypeLen = USM_LENGTH_OID_TRANSFORM;
   DEBUGMSGTL(("snmpv3","set default authentication type: %s\n", cptr));
 }
@@ -111,10 +111,10 @@ get_default_authtype(size_t *len)
 void
 snmpv3_privtype_conf(const char *word, char *cptr)
 {
-  if (strcmp(cptr,"DES") == 0)
+  if (strcasecmp(cptr,"DES") == 0)
     defaultPrivType = SNMP_DEFAULT_PRIV_PROTO;
   else
-    config_perror("unknown privacy type");
+    config_perror("Unknown privacy type");
   defaultPrivTypeLen = SNMP_DEFAULT_PRIV_PROTOLEN;
   DEBUGMSGTL(("snmpv3","set default privacy type: %s\n", cptr));
 }
@@ -146,14 +146,17 @@ snmpv3_secLevel_conf(const char *word, char *cptr)
 {
   char buf[1024];
   
-  if (strcmp(cptr,"noAuthNoPriv") == 0 || strcmp(cptr, "1") == 0)
+  if (strcasecmp(cptr,"noAuthNoPriv") == 0 || strcmp(cptr, "1") == 0
+	|| strcasecmp(cptr, "nanp") == 0)
     ds_set_int(DS_LIBRARY_ID, DS_LIB_SECLEVEL, SNMP_SEC_LEVEL_NOAUTH);
-  else if (strcmp(cptr,"authNoPriv") == 0 || strcmp(cptr, "2") == 0)
+  else if (strcasecmp(cptr,"authNoPriv") == 0 || strcmp(cptr, "2") == 0
+	|| strcasecmp(cptr, "anp") == 0)
     ds_set_int(DS_LIBRARY_ID, DS_LIB_SECLEVEL, SNMP_SEC_LEVEL_AUTHNOPRIV);
-  else if (strcmp(cptr,"authPriv") == 0 || strcmp(cptr, "3") == 0)
+  else if (strcasecmp(cptr,"authPriv") == 0 || strcmp(cptr, "3") == 0
+	|| strcasecmp(cptr, "ap") == 0)
     ds_set_int(DS_LIBRARY_ID, DS_LIB_SECLEVEL, SNMP_SEC_LEVEL_AUTHPRIV);
   else {
-    sprintf(buf,"unknown security level: cptr");
+    sprintf(buf,"Unknown security level: %s", cptr);
     config_perror(buf);
   }
   DEBUGMSGTL(("snmpv3","default secLevel set to: %s = %d\n", cptr,
@@ -323,7 +326,7 @@ usm_parse_create_usmUser(const char *token, char *line) {
     memcpy(newuser->authProtocol, usmHMACSHA1AuthProtocol,
            sizeof(usmHMACSHA1AuthProtocol));
   } else {
-    config_perror("unknown authentication protocol");
+    config_perror("Unknown authentication protocol");
     usm_free_user(newuser);
     return;
   }
@@ -367,7 +370,7 @@ usm_parse_create_usmUser(const char *token, char *line) {
     memcpy(newuser->privProtocol, usmDESPrivProtocol,
            sizeof(usmDESPrivProtocol));
   } else {
-    config_perror("unknown privacy protocol");
+    config_perror("Unknown privacy protocol");
     usm_free_user(newuser);
     return;
   }
@@ -454,12 +457,12 @@ version_conf(const char *word, char *cptr)
 {
   if (strcmp(cptr,"1") == 0) {
     ds_set_int(DS_LIBRARY_ID, DS_LIB_SNMPVERSION, SNMP_VERSION_1);
-  } else if (strcmp(cptr,"2c") == 0) {
+  } else if (strcasecmp(cptr,"2c") == 0) {
     ds_set_int(DS_LIBRARY_ID, DS_LIB_SNMPVERSION, SNMP_VERSION_2c);
   } else if (strcmp(cptr,"3") == 0) {
     ds_set_int(DS_LIBRARY_ID, DS_LIB_SNMPVERSION, SNMP_VERSION_3);
   } else {
-    config_perror("unknown version specification");
+    config_perror("Unknown version specification");
     return;
   }
   DEBUGMSGTL(("snmpv3","set default version to %d\n",
@@ -491,6 +494,10 @@ oldengineID_conf(const char *word, char *cptr)
 void
 init_snmpv3(const char *type) {
   gettimeofday(&snmpv3starttime, NULL);
+
+  if (type == NULL)
+     type = "snmpapp";
+
   if (type && !strcmp(type,"snmpapp")) {
      setup_engineID(NULL,"__snmpapp__");
   } else {
@@ -505,7 +512,7 @@ init_snmpv3(const char *type) {
                          init_snmpv3_post_config, NULL);
   /* we need to be called back later */
   snmp_register_callback(SNMP_CALLBACK_LIBRARY, SNMP_CALLBACK_STORE_DATA,
-                         snmpv3_store, (void *)type);
+                         snmpv3_store, (void *) type);
 
 
 #if		!defined(USE_INTERNAL_MD5)
@@ -517,9 +524,8 @@ init_snmpv3(const char *type) {
 
   /* handle engineID setup before everything else which may depend on it */
   register_premib_handler(type,"engineID", engineID_conf, NULL, "string");
-  register_premib_handler(type,"oldEngineID", oldengineID_conf, NULL,
-                          "len hexEngineId");
-  register_config_handler(type,"engineBoots", engineBoots_conf, NULL, "num");
+  register_premib_handler(type,"oldEngineID", oldengineID_conf, NULL, NULL);
+  register_config_handler(type,"engineBoots", engineBoots_conf, NULL, NULL);
 
   /* default store config entries */
   ds_register_config(ASN_OCTET_STR, "snmp", "defSecurityName", DS_LIBRARY_ID,
